@@ -8,33 +8,92 @@
 #
 
 package CHI::Driver::BerkeleyDB;
-$CHI::Driver::BerkeleyDB::VERSION = '0.04';
+$CHI::Driver::BerkeleyDB::VERSION = '0.05';
 # ABSTRACT: BerkeleyDB Cache Driver for CHI
 
 use strict;
 use warnings;
+
+use Moo;
 use BerkeleyDB 0.30;
 use CHI::Util 0.25 qw(read_dir);
 use File::Path qw(mkpath);
-use Moose;
+use namespace::clean;
 
 extends 'CHI::Driver';
 
-has db => (is => 'ro', lazy_build => 1);
+has db => (is => 'lazy');
 
 has db_class => (is => 'ro', default => 'BerkeleyDB::Hash');
 
-has dir_create_mode => (is => 'ro', isa => 'Int', default => oct(775));
+has dir_create_mode => (is => 'ro', default => oct(775));
 
-has env => (is => 'ro', lazy_build => 1);
+has env => (is => 'lazy');
 
-has filename => (is => 'ro', init_arg => undef, lazy_build => 1);
+has filename => (is => 'lazy', init_arg => undef);
 
 has root_dir => (is => 'ro');
 
+sub fetch {
+    my ($self, $key) = @_;
+
+    my $data;
+
+    return $self->db->db_get($key, $data) == 0 ? $data : undef;
+}
+
+sub store {
+    my ($self, $key, $data) = @_;
+
+    $self->db->db_put($key, $data) == 0
+      or die $BerkeleyDB::Error;
+}
+
+sub remove {
+    my ($self, $key) = @_;
+
+    my $status = $self->db->db_del($key);
+
+    unless ($status == 0 or $status == BerkeleyDB::DB_NOTFOUND()) {
+        die $BerkeleyDB::Error;
+    }
+}
+
+sub clear {
+    my $self = shift;
+
+    my $count = 0;
+
+    $self->db->truncate($count) == 0
+      or die $BerkeleyDB::Error;
+}
+
+sub get_keys {
+    my $self = shift;
+
+    my @keys;
+    my $cursor = $self->db->db_cursor();
+    my ($key, $value) = ('', '');
+
+    while ($cursor->c_get($key, $value, BerkeleyDB::DB_NEXT()) == 0) {
+        push @keys, $key;
+    }
+
+    return @keys;
+}
+
+sub get_namespaces {
+    my $self = shift;
+
+    return
+      map  { $self->unescape_for_filename(substr $_, 0, -3) }
+      grep { /\.db$/ } read_dir($self->root_dir);
+}
+
 sub _build_filename {
     my $self = shift;
-    return $self->escape_for_filename( $self->namespace ) . ".db";
+
+    return $self->escape_for_filename($self->namespace) . ".db";
 }
 
 sub _build_env {
@@ -47,15 +106,15 @@ sub _build_env {
     }
 
     unless (-d $root_dir) {
-        mkpath( $root_dir, 0, $self->dir_create_mode );
+        mkpath($root_dir, 0, $self->dir_create_mode);
     }
 
     my $env = BerkeleyDB::Env->new(
         '-Home'   => $self->root_dir,
         '-Config' => {},
         '-Flags'  => DB_CREATE | DB_INIT_CDB | DB_INIT_MPOOL)
-      or die sprintf( "cannot open Berkeley DB environment in '%s': %s",
-        $root_dir, $BerkeleyDB::Error );
+      or die sprintf "cannot open Berkeley DB environment in '%s': %s",
+        $root_dir, $BerkeleyDB::Error;
 
     return $env;
 }
@@ -68,84 +127,25 @@ sub _build_db {
         '-Filename' => $filename,
         '-Flags'    => DB_CREATE,
         '-Env'      => $self->env)
-      or die
-      sprintf( "cannot open Berkeley DB file '%s' in environment '%s': %s",
-        $filename, $self->root_dir, $BerkeleyDB::Error );
+      or die sprintf "cannot open Berkeley DB file '%s' in environment '%s': %s",
+        $filename, $self->root_dir, $BerkeleyDB::Error;
 
     return $db;
 }
 
-sub fetch {
-    my ($self, $key) = @_;
-
-    my $data;
-
-    return ( $self->db->db_get( $key, $data ) == 0 ) ? $data : undef;
-}
-
-sub store {
-    my ($self, $key, $data) = @_;
-
-    $self->db->db_put( $key, $data ) == 0
-      or die $BerkeleyDB::Error;
-}
-
-sub remove {
-    my ($self, $key) = @_;
-
-    $self->db->db_del($key) == 0
-      or die $BerkeleyDB::Error;
-}
-
-sub clear {
-    my $self = shift;
-
-    my $count = 0;
-    $self->db->truncate($count) == 0
-      or die $BerkeleyDB::Error;
-}
-
-sub get_keys {
-    my $self = shift;
-
-    my @keys;
-    my $cursor = $self->db->db_cursor();
-    my ($key, $value) = ('', '');
-
-    while ( $cursor->c_get( $key, $value, BerkeleyDB::DB_NEXT() ) == 0 ) {
-        push( @keys, $key );
-    }
-
-    return @keys;
-}
-
-sub get_namespaces {
-    my $self = shift;
-
-    my @contents = read_dir( $self->root_dir );
-
-    my @namespaces =
-      map { $self->unescape_for_filename( substr( $_, 0, -3 ) ) }
-      grep { /\.db$/ } @contents;
-
-    return @namespaces;
-}
-
 __PACKAGE__->meta->make_immutable;
 
 __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 CHI::Driver::BerkeleyDB - BerkeleyDB Cache Driver for CHI
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -165,33 +165,37 @@ By default, the driver configures the Berkeley DB environment to use the
 Concurrent Data Store (CDS), making it safe for multiple processes to read and
 write the cache without explicit locking.
 
-=for Pod::Coverage clear fetch get_keys get_namespaces remove store
-
 =head1 CONSTRUCTOR OPTIONS
 
 =over 4
 
 =item *
 
-root_dir
+root_dir: string B<[required]>
 
 Path to the directory that will contain the Berkeley DB environment, also known as the "Home".
 
 =item *
 
-db_class
+db_class: string
 
-BerkeleyDB class, defaults to BerkeleyDB::Hash.
+BerkeleyDB class, defaults to C<BerkeleyDB::Hash>.
 
 =item *
 
-env
+dir_create_mode: integer
+
+The mode to use when creating the database directory if it does not exist.  Defaults to C<oct(775)>.
+
+=item *
+
+env: BerkeleyDB::Env
 
 Use this Berkeley DB environment instead of creating one.
 
 =item *
 
-db
+db: BerkeleyDB object
 
 Use this Berkeley DB object instead of creating one.
 
@@ -218,7 +222,7 @@ L<BerkeleyDB>
 
 =head1 SOURCE
 
-The development version is on github at L<http://https://github.com/mschout/perl-chi-driver-bdb>
+The development version is on github at L<https://https://github.com/mschout/perl-chi-driver-bdb>
 and may be cloned from L<git://https://github.com/mschout/perl-chi-driver-bdb.git>
 
 =head1 BUGS
